from emod_api import schema_to_class as s2c
import emod_api.interventions.common as common
import emod_api.interventions.utils as utils
from emodpy_tbhiv.interventions import purge_campaign_event

def get_thresh( name, low, high, camp ):
    thresh = {}
    thresh["Event"] = camp.get_send_trigger( name )
    thresh["Low"] = low
    thresh["High"] = high
    return thresh

def get_threshes( group_names, camp ):
    threshes = list()
    threshes.append( get_thresh( group_names[0], 0, 200, camp ) )
    threshes.append( get_thresh( group_names[1], 200, 350, camp ) )
    threshes.append( get_thresh( group_names[2], 350, 500, camp ) )
    threshes.append( get_thresh( group_names[3], 500, 20000, camp ) )
    return threshes
 
def CD4Diag(
        camp,
        trigger_treatment_list,
        event_200='Below200',
        event_350='Below350',
        event_500='Below500',
        event_above_500='Above500',
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='CD4 Diagnostic'):
    """
    ART
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path

    intervention = s2c.get_class_with_defaults( "CD4Diagnostic", schema_path )
    intervention.CD4_Thresholds = get_threshes( [ event_200, event_350, event_500, event_above_500 ], camp ) 
    
    event = common.TriggeredCampaignEvent( camp, start_day,event_name, utils.do_nodes( camp.schema_path, nodeIDs ), trigger_treatment_list, [ intervention ], Duration=duration, Property_Restrictions=property_restrictions_list )
    purge_campaign_event( event )

    return event

def new_intervention_as_file( camp, filename="cd4.json" ):
    camp.add( CD4Diag( camp, trigger_treatment_list=[ "Births" ] ) )
    camp.save( filename )
    return filename

