from emod_api import schema_to_class as s2c
import emod_api.interventions.common as common
import emod_api.interventions.utils as utils
from emodpy_tbhiv.interventions import purge_campaign_event

co_event = "TbDrugDistributed"

def TBHIVDrugTreatment(
        camp,
        trigger_treatment_list,
        drug_name,
        latent_multiplier=1.0,
        active_multiplier=1.0,
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='TBHIVDrugTreatment'):
    """
    TBHIVDrugTreatment
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    schema_path = camp.schema_path

    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent", schema_path )
    bcast_intervention.Broadcast_Event = camp.get_send_trigger( co_event ) 
    
    act_intervention = s2c.get_class_with_defaults( "TBHIVConfigurableTBdrug", schema_path )
    act_intervention.TB_Drug_Name = drug_name
    act_intervention.Latency_Multiplier = latent_multiplier
    act_intervention.Active_Multiplier = active_multiplier
    act_intervention.Durability_Profile = 'FIXED_DURATION_CONSTANT_EFFECT'
   
    event = common.TriggeredCampaignEvent( camp, start_day,event_name, utils.do_nodes( camp.schema_path, nodeIDs ), trigger_treatment_list, [ act_intervention, bcast_intervention ], Duration=duration, Property_Restrictions=property_restrictions_list )
    purge_campaign_event( event )

    return event

def new_intervention_as_file( camp, filename="tb_drug_treat.json" ):
    camp.add( TBHIVDrugTreatment( camp, trigger_treatment_list=[ "Births" ], drug_name="DOTS" ) )
    camp.save( filename )
    return filename

